>From 6ac34cfb6c76163c89e047e0a7ea584238390e74 Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Mon, 22 Aug 2011 16:23:31 +0300
Subject: [carFl mem 63/65] Introduce ERROR_FATAL in chipset enables

Currently we are continuing even if chipset enable has failed.
Some chipset enables do exits, so to kill those exits I have
prepared one sneaky check :) Errors are negative there, so I
have chosen this constant.

This patch is proposed for mainline:
http://www.flashrom.org/pipermail/flashrom/2011-August/007695.html

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 chipset_enable.c |    4 ++++
 flash.h          |    3 ++-
 internal.c       |    3 ++-
 3 files changed, 8 insertions(+), 2 deletions(-)

diff --git a/chipset_enable.c b/chipset_enable.c
index d240205..24e97d2 100644
--- a/chipset_enable.c
+++ b/chipset_enable.c
@@ -1288,6 +1288,10 @@ int chipset_flash_enable(globals *g)
 			msg_pinfo("OK.\n");
 		else if (ret == ERROR_NONFATAL)
 			msg_pinfo("PROBLEMS, continuing anyway\n");
+		if (ret == ERROR_FATAL) {
+			msg_perr("FATAL ERROR!\n");
+			return ret;
+		}
 	}
 
 	s = flashbuses_to_text(g->buses_supported);
diff --git a/flash.h b/flash.h
index 2732120..f40070f 100644
--- a/flash.h
+++ b/flash.h
@@ -229,8 +229,9 @@ int write_buf_to_file(unsigned char *buf, unsigned long size, const char *filena
 #define OK 0
 #define NT 1    /* Not tested */
 
-/* Something happened that shouldn't happen, but we can go on */
+/* Something happened that shouldn't happen, but we can go on, or not */
 #define ERROR_NONFATAL 0x100
+#define ERROR_FATAL -0xEE
 
 /* cli_output.c */
 /* Let gcc and clang check for correct printf-style format strings. */
diff --git a/internal.c b/internal.c
index e12c60c..b443a41 100644
--- a/internal.c
+++ b/internal.c
@@ -258,7 +258,8 @@ int internal_init(globals *g)
 	if (ret == -2) {
 		msg_perr("WARNING: No chipset found. Flash detection "
 			 "will most likely fail.\n");
-	}
+	} else if (ret == ERROR_FATAL)
+		return ret;
 
 #if defined(__i386__) || defined(__x86_64__)
 	/* Probe unconditionally for IT87* LPC->SPI translation and for
-- 
1.7.6

